@@ -123,7 +123,9 @@ impl Unmarshal for PictureLossIndication {
         let sender_ssrc = raw_packet.get_u32();
         let media_ssrc = raw_packet.get_u32();
 
-        if h.padding && raw_packet.has_remaining() {
+        if
+        /*h.padding &&*/
+        raw_packet.has_remaining() {
             raw_packet.advance(raw_packet.remaining());
         }
 
