@@ -200,7 +200,9 @@ impl Unmarshal for TransportLayerNack {
             });
         }
 
-        if h.padding && raw_packet.has_remaining() {
+        if
+        /*h.padding &&*/
+        raw_packet.has_remaining() {
             raw_packet.advance(raw_packet.remaining());
         }
 
